@@ -1,3 +1,4 @@
+#!/usr/bin/perl
 # exercise Content.pm as much as possible
 # outputs Content.pdf
 # author: Phil M Perry
@@ -5,8 +6,8 @@
 use warnings;
 use strict;
 
-our $VERSION = '3.009'; # VERSION
-my $LAST_UPDATE = '3.003'; # manually update whenever code is changed
+our $VERSION = '3.010'; # VERSION
+my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
 
 use Math::Trig;
 use List::Util qw(min max);
@@ -18,7 +19,9 @@ use List::Util qw(min max);
 
 use PDF::Builder;
 
-my $PDFname = 'Content.pdf';
+my $PDFname = $0;
+   $PDFname =~ s/\..*$//;  # remove extension
+   $PDFname .= '.pdf';     # add new extension
 my $globalX = 0; 
 my $globalY = 0;
 my $compress = 'none';
@@ -398,18 +401,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -418,6 +423,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -442,18 +448,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(1);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -462,6 +470,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -486,18 +495,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(2);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -506,6 +517,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -536,18 +548,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -556,6 +570,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -580,18 +595,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -600,6 +617,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -624,18 +642,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -644,6 +664,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -668,18 +689,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -688,6 +711,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -712,18 +736,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -732,6 +758,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -756,18 +783,20 @@ $grfx->translate(@base);
 $grfx->linecap(0);
 $grfx->linejoin(0);
 
+# draw red, including miter or bevel joint per setting (all that will show)
 $grfx->strokecolor('red');
 $grfx->linewidth($lw);
 $grfx->poly(@points);
 $grfx->stroke();
 
+# draw black each of the two thick bars (butt linecap), overlaying most red
 $grfx->strokecolor('black');
-for ($i=0; $i<@points; $i+=2) {
+for ($i=0; $i<scalar(@points)-2; $i+=2) {
   $grfx->poly($points[$i],$points[$i+1], $points[$i+2],$points[$i+3]);
   $grfx->stroke();
 }
 
-# gray overlap
+# gray overlap of bars, as custom-written filled shape
 $grfx->fillcolor('#333333');
 $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 @npts = ($points[2], $points[3], $points[2], $points[3]+$lw/2,
@@ -776,6 +805,7 @@ $angle = atan2($points[5]-$points[3], $points[4]-$points[2]);
 $grfx->poly(@npts);
 $grfx->close();
 $grfx->fill();
+# dots and green centerline
 greenLine(\@points);
 
 # caption
@@ -1136,7 +1166,7 @@ drawCaption(['curve()'], 'LC');
 $grfx->restore();
 
 # ----------------------------------------------------
-# 28. spline()  (cubic Bezier curve with synthesized control points)
+# 28. qbspline()  (cubic Bezier curve with synthesized control points)
 @cellLoc = makeCellLoc(0);
 @cellSize = (170, 131); 
 $grfx->save();
@@ -1154,17 +1184,93 @@ $grfx->translate(@base);
 @points = (40,75, 130,60); # EP1=20,20, CP1, EP2
 $grfx->linedash();
 $grfx->move(20, 20);
-$grfx->spline(@points);
+$grfx->qbspline(@points);
 $grfx->stroke();
 $grfx->linedash(4);
 greenLine([20, 20, @points]);
 $grfx->strokecolor('black');
 
 # caption
-drawCaption(['spline()'], 'LC');
+drawCaption(['qbspline()'], 'LC');
 
 $grfx->restore();
 
+# ----------------------------------------------------
+# 28A. qbspline()  (multipiece spline, and with line segment)
+@cellLoc = makeCellLoc(0);
+@cellSize = (170, 131); 
+$grfx->save();
+
+makeCell(@cellLoc, @cellSize);
+@base=@cellLoc;
+$base[0] += 10;
+$base[1] += 10;
+
+$grfx->strokecolor('black');
+$grfx->linewidth(2);
+$text->font($fontC, 8);
+$grfx->translate(@base);
+
+@points = (40,95, 50,70, 80,100, 130,70); # EP1=20,50, CP1, P2, CP2, P3
+$grfx->linedash();
+$grfx->move(20, 50);
+$grfx->qbspline(@points);
+$grfx->stroke();
+$grfx->linedash(4);
+greenLine([20, 50, @points]);
+$grfx->strokecolor('black');
+
+# currently excess point P4 is not drawn (line) as part of the qbspline
+@points = (40,55, 50,30, 80,60, 130,30, 135,10); # EP1=20,10, CP1, P2, CP2, P3, P4
+$grfx->linewidth(2);
+$grfx->linedash();
+$grfx->move(20, 10);
+$grfx->qbspline(@points);
+$grfx->stroke();
+$grfx->linedash(4);
+greenLine([20, 10, @points]);
+$grfx->strokecolor('black');
+
+# caption
+drawCaption(['multi qbspline()'], 'LC');
+
+$grfx->restore();
+
+# ----------------------------------------------------
+# 28B. bspline()  (multipiece cubic Bezier spline)
+@cellLoc = makeCellLoc(0);
+@cellSize = (170, 131); 
+$grfx->save();
+
+makeCell(@cellLoc, @cellSize);
+@base=@cellLoc;
+$base[0] += 10;
+$base[1] += 10;
+
+$grfx->strokecolor('black');
+$grfx->linewidth(2);
+$text->font($fontC, 8);
+$grfx->translate(@base);
+
+@points = (0,0, 20,40, 70,50, 115,40, 145,35, 145,45, 115,40, 70,5); 
+$grfx->linedash();
+$grfx->move(0,0);
+$grfx->bspline(\@points, -debug=>4);
+$grfx->stroke();
+
+@points = (0,65, 20,105, 70,115, 115,105, 145,100, 145,110, 115,105, 70,70); 
+$grfx->linedash();
+$grfx->move(0,65);
+$grfx->bspline(\@points, -debug=>1);
+$grfx->stroke();
+
+# caption
+drawCaption(['bspline() with', 'constructors'], 'LC');
+
+$grfx->restore();
+
+# ----------------------------------------------------
+
 # ----------------------------------------------------
 # 29. bogen()  (circular arc segment) 1/4  smaller arc, non-flipped
 @cellLoc = makeCellLoc(0);
@@ -1380,7 +1486,7 @@ $grfx->restore();
 
 # ----------------------------------------------------
 # 33. fill(): 5 pt star with both rules
-@cellLoc = makeCellLoc(0);
+@cellLoc = makeCellLoc(1);
 @cellSize = (170, 131); 
 $grfx->save();
 
@@ -2231,6 +2337,7 @@ sub colors {
   $grfx->fillcolor($color);
   $text->strokecolor($color);
   $text->fillcolor($color);
+  return;
 }
 
 # ---------------------------------------
@@ -2255,6 +2362,7 @@ sub greenLine {
     $grfx->poly($points[$i],$points[$i+1], $points[$i],$points[$i+1]);
   }
   $grfx->stroke();
+  return;
 }
 
 # ---------------------------------------
@@ -2269,6 +2377,7 @@ sub nextPage {
   $text->font($font, 10);
   $text->fillcolor('black');
   $text->text_center($pageNo); # prefill page number before any other content
+  return;
 }
 
 # ---------------------------------------
@@ -2287,6 +2396,7 @@ sub makeCell {
  #$text->linewidth(1);
  #$text->rect($cellLocX,$cellLocY, $cellSizeW,$cellSizeH);
  #$text->clip(1);
+  return;
 }
 
 # ---------------------------------------
@@ -2315,7 +2425,7 @@ sub drawAxes {
   	      $axisOffset[0]+0+0, $axisOffset[1]+75+0, 
  	      $axisOffset[0]+0+2, $axisOffset[1]+75-2);
   $grfx->stroke();
-
+  return;
 }
 
 # ---------------------------------------
@@ -2342,7 +2452,7 @@ sub drawLabels {
   # Y axis label
   $text->distance(-75-2+0-4, 0+3+75+2);
   $text->text($Ylabel);
-
+  return;
 }
 
 # ---------------------------------------
@@ -2363,11 +2473,14 @@ sub drawCaption {
     $width = max($width, $text->advancewidth($_));
   }
 
-  for ($i=0, $y=20; $i<@captions; $i++, $y+=13) {
+  $y=20;  # to shut up perlcritic
+  for ($i=0; $i<@captions; $i++) {
     # $just = LC
     $text->translate($cellLoc[0]+$cellSize[0]/2-$width/2, $cellLoc[1]-$y);
     $text->text($captions[$i]);
+    $y+=13;  # to mollify perlcritic
   }
+  return;
 }
 
 # ---------------------------------------
