@@ -1,3 +1,4 @@
+#!/usr/bin/perl
 # exercise Content/Text.pm as much as possible
 # outputs ContentText.pdf
 # author: Phil M Perry
@@ -5,8 +6,8 @@
 use warnings;
 use strict;
 
-our $VERSION = '3.009'; # VERSION
-my $LAST_UPDATE = '3.003'; # manually update whenever code is changed
+our $VERSION = '3.010'; # VERSION
+my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
 
 use Math::Trig;
 use List::Util qw(min max);
@@ -18,7 +19,9 @@ use List::Util qw(min max);
 
 use PDF::Builder;
 
-my $PDFname = 'ContentText.pdf';
+my $PDFname = $0;
+   $PDFname =~ s/\..*$//;  # remove extension
+   $PDFname .= '.pdf';     # add new extension
 my $globalX = 0; 
 my $globalY = 0;
 
@@ -1383,6 +1386,7 @@ sub colors {
   $grfx->fillcolor($color);
   $text->strokecolor($color);
   $text->fillcolor($color);
+  return;
 }
 
 # ---------------------------------------
@@ -1407,6 +1411,7 @@ sub greenLine {
     $grfx->poly($points[$i],$points[$i+1], $points[$i],$points[$i+1]);
   }
   $grfx->stroke();
+  return;
 }
 
 # ---------------------------------------
@@ -1421,6 +1426,7 @@ sub nextPage {
   $text->font($font, 10);
   $text->fillcolor('black');
   $text->text_center($pageNo); # prefill page number before any other content
+  return;
 }
 
 # ---------------------------------------
@@ -1439,6 +1445,7 @@ sub makeCell {
  #$text->linewidth(1);
  #$text->rect($cellLocX,$cellLocY, $cellSizeW,$cellSizeH);
  #$text->clip(1);
+  return;
 }
 
 # ---------------------------------------
@@ -1467,7 +1474,7 @@ sub drawAxes {
   	      $axisOffset[0]+0+0, $axisOffset[1]+75+0, 
  	      $axisOffset[0]+0+2, $axisOffset[1]+75-2);
   $grfx->stroke();
-
+  return;
 }
 
 # ---------------------------------------
@@ -1494,7 +1501,7 @@ sub drawLabels {
   # Y axis label
   $text->distance(-75-2+0-4, 0+3+75+2);
   $text->text($Ylabel);
-
+  return;
 }
 
 # ---------------------------------------
@@ -1515,11 +1522,14 @@ sub drawCaption {
     $width = max($width, $text->advancewidth($_));
   }
 
-  for ($i=0, $y=20; $i<@captions; $i++, $y+=13) {
+  $y=20; # shut up perlcritic
+  for ($i=0; $i<@captions; $i++) {
     # $just = LC
     $text->translate($cellLoc[0]+$cellSize[0]/2-$width/2, $cellLoc[1]-$y);
     $text->text($captions[$i]);
+    $y+=13; # shut up perlcritic
   }
+  return;
 }
 
 # ---------------------------------------
