@@ -17,12 +17,13 @@ use base 'PDF::Builder::Basic::PDF::Objind';
 use strict;
 use warnings;
 
-our $VERSION = '3.009'; # VERSION
-my $LAST_UPDATE = '3.004'; # manually update whenever code is changed
+our $VERSION = '3.010'; # VERSION
+my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Basic::PDF::Array - Corresponds to a PDF array. Inherits from L<PDF::Objind>
+PDF::Builder::Basic::PDF::Array - Corresponds to a PDF array. 
+Inherits from L<PDF::Builder::Basic::PDF::Objind>
 
 =head1 METHODS
 
@@ -59,6 +60,7 @@ sub outobjdeep {
         $fh->print(' ');
     }
     $fh->print(']');
+    return;
 }
 
 =head2 $a->removeobj($elem)
@@ -70,7 +72,8 @@ Removes all occurrences of an element from an array.
 sub removeobj {
     my ($self, $elem) = @_;
 
-    $self->{' val'} = [grep($_ ne $elem, @{$self->{' val'}})];
+    $self->{' val'} = [grep($_ ne $elem, @{$self->{' val'}})];  ## no critic
+    return $self;
 }
 
 =head2 $a->elementsof()
