@@ -17,8 +17,8 @@ no warnings qw[ deprecated recursion uninitialized ];
 
 use base 'PDF::Builder::Basic::PDF::Dict';
 
-our $VERSION = '3.009'; # VERSION
-my $LAST_UPDATE = '3.004'; # manually update whenever code is changed
+our $VERSION = '3.010'; # VERSION
+my $LAST_UPDATE = '3.010'; # manually update whenever code is changed
 
 use PDF::Builder::Basic::PDF::Array;
 use PDF::Builder::Basic::PDF::Dict;
@@ -68,14 +68,14 @@ sub new {
     weaken $_ for @{$self->{' outto'}};
     weaken $self->{'Parent'} if defined $parent;
 
-    $self;
+    return $self;
 }
 
 sub init {
     my ($self, $pdf) = @_;
     $self->{' outto'} = [$pdf];
     weaken $self->{' outto'}->[0] if defined $pdf;
-    $self;
+    return $self;
 }
 
 =head2 $p->out_obj($isnew)
@@ -103,7 +103,7 @@ sub out_obj {
             $_->out_obj($_->{'Root'});
         }
     }
-    $self;
+    return $self;
 }
 
 =head2 $p->find_page($pnum)
@@ -118,7 +118,7 @@ sub find_page {
 
     my ($top) = $self->get_top();
 
-    $top->find_page_recurse(\$pnum);
+    return $top->find_page_recurse(\$pnum);
 }
 
 sub find_page_recurse {
@@ -195,7 +195,7 @@ sub add_page {
         $ppages->out_obj()->{'Count'}->realise()->{'val'}++;
     }
     $ppages->out_obj()->{'Count'}->realise()->{'val'}++;
-    $page;
+    return $page;
 } # end of add_page()
 
 sub add_page_recurse {
@@ -226,6 +226,7 @@ sub add_page_recurse {
     }
     $page->{'Parent'} = $newpages;
     weaken $page->{'Parent'};
+    return;
 } # end of add_page_recurse()
 
 =head2 $root_pages = $p->rebuild_tree([@pglist])
@@ -243,6 +244,7 @@ Returns the top of the tree for insertion in the root object.
 # TBD where's the code?
 sub rebuild_tree {
     my ($self, @pglist) = @_;
+    return;
 }
 
 =head2 @pglist = $p->get_pages()
@@ -271,7 +273,7 @@ sub get_kids {
 	    push (@pglist, $pgref);
         }
     }
-    @pglist;
+    return @pglist;
 }
 
 =head2 $p->find_prop($key)
@@ -328,7 +330,7 @@ sub add_font {
     if (ref $rdict ne 'HASH' && $rdict->is_obj($pdf)) {
         $pdf->out_obj($rdict);
     }
-    $self;
+    return $self;
 } # end of add_font()
 
 =head2 $p->bbox($xmin,$ymin, $xmax,$ymax, [$param])
@@ -360,7 +362,7 @@ sub bbox {
         $inh->add_elements(PDFNum($e));
     }
     $self->{$str} = $inh;
-    $self;
+    return $self;
 }
 
 =head2 $p->proc_set(@entries)
@@ -379,7 +381,7 @@ sub proc_set {
     $dict = $self->find_prop('Resource');
     if ($dict ne "" && defined $dict->{'ProcSet'}) {
         foreach my $e ($dict->{'ProcSet'}->elementsof()) { 
-	    @temp = grep($_ ne $e, @temp); 
+	    @temp = grep($_ ne $e, @temp);  ## no critic
         }
         return $self if (scalar @temp == 0);
         @entries = @temp if defined $self->{'Resources'};
@@ -394,7 +396,7 @@ sub proc_set {
     foreach my $e (@entries) { 
 	$self->{'Resources'}{'ProcSet'}->add_elements(PDFName($e)); 
     }
-    $self;
+    return $self;
 } # end of proc_set()
 
 sub empty {
@@ -407,7 +409,7 @@ sub empty {
         $self->{'Parent'} = $parent;
         weaken $self->{'Parent'};
     }
-    $self;
+    return $self;
 }
 
 sub dont_copy {
@@ -428,7 +430,7 @@ sub get_top {
     for ($p = $self; defined $p->{'Parent'}; $p = $p->{'Parent'})
     { } # simply looping until run out of Parents. equivalent:  ;
 
-    $p->realise();
+    return $p->realise();
 }
 
 1;
